==> istio-model-v1beta1-6.8.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/HTTPFaultInjectionAbortGrpcStatusFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HTTPFaultInjectionAbortGrpcStatusFluent<A extends HTTPFaultInjectionAbortGrpcStatusFluent<A>> extends BaseFluent<A>{
  public HTTPFaultInjectionAbortGrpcStatusFluent() {
  }
  public HTTPFaultInjectionAbortGrpcStatusFluent(HTTPFaultInjectionAbortGrpcStatus instance) {
    instance = (instance != null ? instance : new HTTPFaultInjectionAbortGrpcStatus());

    if (instance != null) {
      this.withGrpcStatus(instance.getGrpcStatus());
      this.withGrpcStatus(instance.getGrpcStatus());
    }
  }
  private String grpcStatus;
  public String getGrpcStatus() {
    return this.grpcStatus;
  }
  public A withGrpcStatus(String grpcStatus) {
    this.grpcStatus=grpcStatus; return (A) this;
  }
  public boolean hasGrpcStatus() {
    return this.grpcStatus != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HTTPFaultInjectionAbortGrpcStatusFluent that = (HTTPFaultInjectionAbortGrpcStatusFluent) o;
    if (!java.util.Objects.equals(grpcStatus, that.grpcStatus)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(grpcStatus,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (grpcStatus != null) { sb.append("grpcStatus:"); sb.append(grpcStatus); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1beta1-6.9.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/HTTPFaultInjectionAbortGrpcStatusFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class HTTPFaultInjectionAbortGrpcStatusFluent<A extends HTTPFaultInjectionAbortGrpcStatusFluent<A>> extends BaseFluent<A>{
  public HTTPFaultInjectionAbortGrpcStatusFluent() {
  }
  
  public HTTPFaultInjectionAbortGrpcStatusFluent(HTTPFaultInjectionAbortGrpcStatus instance) {
    this.copyInstance(instance);
  }
  private String grpcStatus;
  
  protected void copyInstance(HTTPFaultInjectionAbortGrpcStatus instance) {
    instance = (instance != null ? instance : new HTTPFaultInjectionAbortGrpcStatus());
  
    if (instance != null) {
        this.withGrpcStatus(instance.getGrpcStatus());
        this.withGrpcStatus(instance.getGrpcStatus());
      }
  }
  
  public String getGrpcStatus() {
    return this.grpcStatus;
  }
  
  public A withGrpcStatus(String grpcStatus) {
    this.grpcStatus=grpcStatus; return (A) this;
  }
  
  public boolean hasGrpcStatus() {
    return this.grpcStatus != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HTTPFaultInjectionAbortGrpcStatusFluent that = (HTTPFaultInjectionAbortGrpcStatusFluent) o;
    if (!java.util.Objects.equals(grpcStatus, that.grpcStatus)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(grpcStatus,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (grpcStatus != null) { sb.append("grpcStatus:"); sb.append(grpcStatus); }
    sb.append("}");
    return sb.toString();
  }
  

}
